==> topia-persistence-2.9.1-sources.jar: org/nuiton/topia/persistence/csv/in/ImportModelFactory.java <==
package org.nuiton.topia.persistence.csv.in;
/*
 * #%L
 * ToPIA :: Persistence
 * $Id: ImportModelFactory.java 3046 2014-04-03 17:43:45Z athimel $
 * $HeadURL: https://svn.nuiton.org/topia/tags/topia-2.9.1/topia-persistence/src/main/java/org/nuiton/topia/persistence/csv/in/ImportModelFactory.java $
 * %%
 * Copyright (C) 2004 - 2014 CodeLutin
 * %%
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as 
 * published by the Free Software Foundation, either version 3 of the 
 * License, or (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Lesser Public License for more details.
 * 
 * You should have received a copy of the GNU General Lesser Public 
 * License along with this program.  If not, see
 * <http://www.gnu.org/licenses/lgpl-3.0.html>.
 * #L%
 */

import org.nuiton.topia.persistence.TopiaEntity;
import org.nuiton.topia.persistence.TopiaEntityEnum;
import org.nuiton.topia.persistence.metadata.AssociationMeta;
import org.nuiton.topia.persistence.metadata.TableMeta;
import org.nuiton.csv.ImportModel;

import java.util.Map;

/**
 * To produce import model.
 *
 * @author tchemit <chemit@codelutin.com>
 * @since 2.6.12
 */
public interface ImportModelFactory<T extends TopiaEntityEnum> {

    <E extends TopiaEntity> ImportModel<E> buildForImport(TableMeta<T> meta);

    ImportModel<Map<String, Object>> buildForImport(AssociationMeta<T> meta);

    boolean isNMAssociationMeta(AssociationMeta<T> meta);
}

==> topia-persistence-2.9.5.4-sources.jar: org/nuiton/topia/persistence/csv/in/ImportModelFactory.java <==
package org.nuiton.topia.persistence.csv.in;
/*
 * #%L
 * ToPIA :: Persistence
 * $Id$
 * $HeadURL$
 * %%
 * Copyright (C) 2004 - 2014 CodeLutin
 * %%
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as 
 * published by the Free Software Foundation, either version 3 of the 
 * License, or (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Lesser Public License for more details.
 * 
 * You should have received a copy of the GNU General Lesser Public 
 * License along with this program.  If not, see
 * <http://www.gnu.org/licenses/lgpl-3.0.html>.
 * #L%
 */

import org.nuiton.topia.persistence.TopiaEntity;
import org.nuiton.topia.persistence.TopiaEntityEnum;
import org.nuiton.topia.persistence.metadata.AssociationMeta;
import org.nuiton.topia.persistence.metadata.TableMeta;
import org.nuiton.csv.ImportModel;

import java.util.Map;

/**
 * To produce import model.
 *
 * @author tchemit <chemit@codelutin.com>
 * @since 2.6.12
 */
public interface ImportModelFactory<T extends TopiaEntityEnum> {

    <E extends TopiaEntity> ImportModel<E> buildForImport(TableMeta<T> meta);

    ImportModel<Map<String, Object>> buildForImport(AssociationMeta<T> meta);

    boolean isNMAssociationMeta(AssociationMeta<T> meta);
}
